@@ -48,7 +48,19 @@ from sure.registry import context as _registry
 if PY3:
     basestring = str
 
-version = '1.2.25'
+version = '1.3.0'
+
+
+def print_py26_deprecation_warn():
+    # warn the user if sure is used with python 2.6.
+    # sure will remove python 2.6 support in the next version.
+    # make sure to remove this code as soon as the python 2.6 support is removed
+    if sys.version_info[0] == 2 and sys.version_info[1] == 6:
+        import warnings
+        warnings.simplefilter("always", PendingDeprecationWarning)
+        warnings.warn("The next version of sure will NO LONGER support python 2.6", PendingDeprecationWarning)
+
+print_py26_deprecation_warn()
 
 
 not_here_error = \
@@ -435,13 +447,13 @@ class IdentityAssertion(object):
 
 
 class AssertionBuilder(object):
-    def __init__(self, name=None, negative=False, obj=None):
+    def __init__(self, name=None, negative=False, obj=None, callable_args=None, callable_kw=None):
         self._name = name
         self.negative = negative
 
         self.obj = obj
-        self._callable_args = []
-        self._callable_kw = {}
+        self._callable_args = callable_args or []
+        self._callable_kw = callable_kw or {}
         self._that = AssertionHelper(self.obj)
 
     def __call__(self, obj):
@@ -463,7 +475,8 @@ class AssertionBuilder(object):
         negative = attr in NEGATIVES
 
         if special_case:
-            return AssertionBuilder(attr, negative=negative, obj=self.obj)
+            return AssertionBuilder(attr, negative=negative, obj=self.obj,
+                 callable_args=self._callable_args, callable_kw=self._callable_kw)
 
         return super(AssertionBuilder, self).__getattribute__(attr)
 
@@ -868,10 +881,11 @@ class AssertionBuilder(object):
 
     @assertionmethod
     def contain(self, what):
+        obj = self.obj
         if self.negative:
-            return expect(what).to.not_be.within(self.obj)
+            return expect(what).to.not_be.within(obj)
         else:
-            return expect(what).to.be.within(self.obj)
+            return expect(what).to.be.within(obj)
 
     @assertionmethod
     def match(self, regex, *args):
